/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */
#ifndef __GdomDOMSelection_H__
#define __GdomDOMSelection_H__
#include <webkit/webkitdefines.h>
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomNode.h"
#include "gdom/GdomRange.h"
#include "glib-object.h"


G_BEGIN_DECLS

typedef struct _GdomDOMSelection GdomDOMSelection;
typedef struct _GdomDOMSelectionClass GdomDOMSelectionClass;


#define GDOM_TYPE_DOM_SELECTION            (gdom_dom_selection_get_type())
#define GDOM_DOM_SELECTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GDOM_TYPE_DOM_SELECTION, GdomDOMSelection))
#define GDOM_DOM_SELECTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  GDOM_TYPE_DOM_SELECTION, GdomDOMSelection)Class)
#define GDOM_IS_DOM_SELECTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GDOM_TYPE_DOM_SELECTION))
#define GDOM_IS_DOM_SELECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  GDOM_TYPE_DOM_SELECTION))
#define GDOM_DOM_SELECTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  GDOM_TYPE_DOM_SELECTION, GdomDOMSelectionClass))

typedef struct _GdomDOMSelectionPrivate GdomDOMSelectionPrivate;

struct _GdomDOMSelection {
    GdomDOMObject parent_instance;
    GdomDOMSelectionPrivate *priv;
};

struct _GdomDOMSelectionClass {
    GObjectClass parent_class;
};

WEBKIT_API GType
gdom_dom_selection_get_type (void);

WEBKIT_API void
gdom_dom_selection_collapse (GdomDOMSelection *thiz, GdomNode * node, glong index);

WEBKIT_API void
gdom_dom_selection_collapse_to_end (GdomDOMSelection *thiz);

WEBKIT_API void
gdom_dom_selection_collapse_to_start (GdomDOMSelection *thiz);

WEBKIT_API void
gdom_dom_selection_delete_from_document (GdomDOMSelection *thiz);

WEBKIT_API gboolean
gdom_dom_selection_contains_node (GdomDOMSelection *thiz, GdomNode * node, gboolean allow_partial);

WEBKIT_API void
gdom_dom_selection_select_all_children (GdomDOMSelection *thiz, GdomNode * node);

WEBKIT_API void
gdom_dom_selection_empty (GdomDOMSelection *thiz);

WEBKIT_API void
gdom_dom_selection_set_base_and_extent (GdomDOMSelection *thiz, GdomNode * base_node, glong base_offset, GdomNode * extent_node, glong extent_offset);

WEBKIT_API void
gdom_dom_selection_set_position (GdomDOMSelection *thiz, GdomNode * node, glong offset);

WEBKIT_API void
gdom_dom_selection_modify (GdomDOMSelection *thiz, gchar * alter, gchar * direction, gchar * granularity);

WEBKIT_API void
gdom_dom_selection_extend (GdomDOMSelection *thiz, GdomNode * node, glong offset);

WEBKIT_API GdomRange *
gdom_dom_selection_get_range_at (GdomDOMSelection *thiz, glong index);

WEBKIT_API void
gdom_dom_selection_remove_all_ranges (GdomDOMSelection *thiz);

WEBKIT_API void
gdom_dom_selection_add_range (GdomDOMSelection *thiz, GdomRange * range);

WEBKIT_API gchar *
gdom_dom_selection_to_string (GdomDOMSelection *thiz);

G_END_DECLS

#endif /* __GdomDOMSelection_H__ */
